
	org $2000
	rorg $1000

;--------------------------------------------------------------------------
; Levels
;--------------------------------------------------------------------------
; 0 = Main outside area
; 1 = inside small castle
; 2 = passageway under small castle
;
;


;--------------------------------------------------------------------------
; getLevel
;--------------------------------------------------------------------------
; read room definition into cmdBuf
;--------------------------------------------------------------------------
getLevel

	; Set up pointer to row multiplier table
	; for current level
	ldx location
	lda lvlRowMultiplier,x
	sta startX
	lda >rowMultipliers
	sta startY
	lda lvlTileSet,x
	sta tileSet

	ldx temp2	; move current cell into X

	; Get pointer to row
	lda locX

	lsr ; high nibble = room X
	lsr
	lsr
	lsr

	clc
	adc roomX,x    ; x = current cell (0-3)
	tay
	lda locY
	lsr 				; high nibble = room Y pos
	lsr
	lsr
	lsr
	clc
	adc roomY,x		; x = current cell (0-3)
	clc
	adc (startX),y	; get row offset in level data
	tay

	; LEVELS SHOULD BE DESIGNED SO THIS SHOULDN'T BE NECESSARY (I THINK?)
	; Check for overstepping end of level data
	;cpy levelSize
	;bmi inLevelData
	;rts
;inLevelData

	ldx location			; - Set up pointer to screen offset table
	lda lvlScreenPtrL,x	; |
	sta startX				; |
	lda lvlScreenPtrH,x	; |
	sta startY				; -

	ldx location			; - Set up pointer to level definition
	lda #0					; |
	sta width				; |
	lda lvlPagePtr,x		; |
	sta height				; -

	iny
	lax (startX),y 	; get pointer to start of next screen def
	dex					; back up one so we're at the end of the current def
	stx temp				; save it

	dey					; - subtract the start of the current one to get the # of bytes in screen def
	sec					; |
	sbc (startX),y		; -

	tax
	stx temp4			; save number of bytes in def
	dex

	ldy temp				; get pointer to end of level def back

	; Copy the current screen def into the command buffer (cmdBuf)
copyDef:
	lda (width),y
	sta cmdBuf,x
	dey
	dex
	bpl copyDef

	; Get the pointer to the current screen definition
;	ldx ScreenPointer,y
;	sta temp4

	jmp rtnGetLevel

roomX
	byte 0,1,0,1
roomY
	byte 0,0,1,1


;--------------------------------------------------------------------------
; specialCheck
;--------------------------------------------------------------------------
; check for special events on the current tile
;--------------------------------------------------------------------------
specialCheck

	lda #TILE_NOTHING
	sta specResult ; this location indicates the result of this function
						; 0 = not a special tile

	ldx location			; - get pointers to current level's special event table
	lda lvlSpecLow,x		; |
	sta temp					; |
	lda lvlSpecHigh,x    ; |
	sta temp2				; -
	
	ldy #0
	ldx tempY
	jmp specialLoop
reloop1
	iny
reloop2
	iny
	iny
	iny
specialLoop
	lda (temp),y
	beq quitSpecial	; value of 0 = end of list, so quit
	cmp tempX				; see if X value of event = current X location
	bne reloop1	
	iny
	txa
	cmp (temp),y		; see if Y value of event = current Y location
	bne reloop2
	iny
	lda (temp),y		; get event code
	; ********* LATER ADD SUPPORT FOR OTHER SPECIAL MAP EVENTS HERE **********
	iny
	lda (temp),y		; assume it's a map transport, so this byte is the map transport list reference
	tax

	lda specChkSet ; determine whether we're just checking the location, or actually setting it
	beq justCheck

	lda mapTransportMap,x
	sta location
	lda mapTransportX,x
	sta locX
	lda mapTransportY,x
	sta locY

	; code to start screen reload
	lda #M_LOAD
	sta mode
	lda #C_LOAD
	sta mode_cnt

justCheck
	lda #TILE_TRANSPORT
	sta specResult ; indicate that a transport was activated

	lda flag
	ora #FLAG_MAP_TRANSPORT
	sta flag

quitSpecial

	jmp rtnSpecialCheck



;--------------------------------------------------------------------------
; Special Map Events
;--------------------------------------------------------------------------
; 1st byte = [X location]
; 2nd byte = [Y location]
; 3rd byte = [high 000=event type, low 00000=condition]
; 4th byte = [event data]
;
; X location:
; 0 = last event in list
;
; event types:
; 000 = transport to another map, byte 4 = map transport point (map# and location stored in another array)
; 001 = allows character to pass through the tile regardless of type, byte 4 unused
; 010 = talk to a character/enter a shop, byte 4 = character encounter number
; 011 = item, byte 4 = item type
; 100 = stationary monster, byte 4 = monster type
; 101 = custom code, byte 4 = custom code to execute
;--------------------------------------------------------------------------

	; Map transport points Map, X location, Y location
mapTransportMap ; map numbers to transport to
      ; 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0
	byte 1,0,2,1,3,0,4,0,5,4
mapTransportX   ; transport to X loc
	    ;  0   1   2   3   4   5   6   7   8   9   0   1   2   3   4
	byte $20,$18,$07,$07,$10,$10,$02,$69,$30,$30
mapTransportY   ; transport to Y loc
	byte $14,$20,$07,$14,$14,$09,$38,$38,$70,$07

lvlSpec0 ; main area
	byte $18,$19,%00000000,0 ; to inside castle
	byte $09,$09,%00000000,4 ; top left hut
	byte $70,$38,%00000000,6 ; to scary forest
	byte 0 ; last event

lvlSpec1 ; small castle
	byte $20,$15,%00000000,1 ; door to main area
	byte $06,$14,%00000000,2 ; stairs to underground passage
	byte 0 ; last event

lvlSpec2 ; underground passage
	byte $06,$07,%00000000,3 ; back to castle
	byte 0 ; last event

lvlSpec3 ; top left hut
	byte $10,$15,%00000000,5 ; door to main area
	byte 0

lvlSpec4 ; scary forest
	byte $01,$38,%00000000,7 ; to main area
	byte $30,$06,%00000000,8 ; to mountain
	byte 0

lvlSpec5 ; mountain
	byte $30,$71,%00000000,9
	byte 0

lvlSpec6 ; ???
	byte 0
	
lvlSpec7 ; ???
	byte 0
	
	; level pointers
lvlPagePtr
	byte >levelData0,>levelData1,>levelData2,>levelData3,>levelData4,>levelData5,>levelData6,>levelData7
lvlRowMultiplier ; indicates the number of vertical pages in the map
	byte <times8,<times3,<times5,<times3,<times8,<times8,<times8,<times8
lvlScreenPtrL
	byte <scptr0,<scptr1,<scptr2,<scptr3,<scptr4,<scptr5,<scptr6,scptr7
lvlScreenPtrH
	byte >scptr0,>scptr1,>scptr2,>scptr3,>scptr4,>scptr5,>scptr6,>scptr7
lvlTileSet
	byte 0,1,1,1,2,3,4,0
lvlSpecLow
	byte <lvlSpec0,<lvlSpec1,<lvlSpec2,<lvlSpec3,<lvlSpec4,<lvlSpec5,<lvlSpec6,<lvlSpec7
lvlSpecHigh
	byte >lvlSpec0,>lvlSpec1,>lvlSpec2,>lvlSpec3,>lvlSpec4,>lvlSpec5,>lvlSpec6,>lvlSpec7

; Pointer to each row in the screen pointer (x8 in this case)
	align 256
rowMultipliers
times3
	byte 0,3,6,9,12
times5
	byte 0,5,10,15,20,25
times4
	byte 0,4,8,12,16,20,24,28,32,36
times8
	byte 0,8,16,24,32,40,48,56

;--------------------------------------------------------------------------
; Level Data                                                              
;--------------------------------------------------------------------------
; Two Byte Codes                      |  Single Byte Codes                  
; --------------                      |  -----------------                  
; First byte is X/Y coordinate        |                                     
; (from top left of 10x10 area)       |  %0000 0000                         
;                                     |   Code XPos                         
; Second byte = object code:          |    - or -                           
; %0 0000 000                         |  %0000 0000                         
;  | \  / \ |                         |   YPos Code                         
;  |  \/   \|                         |                                     
;  |   |    |_Object type/Special     |  $A full row or column water        
;  |   |                              |  $B full screen of huts
;  |   |_Shape                        |  $C triple row/col of random trees
;  |                                  |  $D half screen of random trees
;  |_Special                          |  $E half screen of random rocks
;                    Shapes           |  $F full screen of water            
; Object Type        0 0000 1X1       |                                   
; 000 = Water        1 0001 2X1       |-------------------------------------                                   
; 001 = Rock         2 0010 1X2       |                                                                        
; 010 = Wall         3 0011 4X1       |  Tiles                                                                  
; 011 = Door                          |  0 0000 Grass   8 1000 MonsterA                                         
; 100 = TreeA        4 0100 1X4       |  1 0001 WaterA  9 1001 MonsterB                                         
; 101 = TreeB        5 0101 2X2       |  2 0010 Gate    a 1010 MonsterC     
; 110 = Gate         6 0110 4X3       |  3 0011 WaterB  b 1011 MonsterD     
; 111 = Hut          7 0111 8X10      |                                                 
;                                     |  4 0100 TreeA   c 1100 Wall                     
; Special            8 1000 10X1      |  5 0101 TreeB   d 1101 Door         
; 000 = Rand Trees   9 1001 1X10      |  6 0110 RockA   e 1110 Hut                      
; 001 = Rand rocks   a 1010 5X1       |  7 0111 RockB   f 1111 Homestar                
; 010 = Water B      b 1011 1X5       |            
; 011 = Rock B                        |-------------------------------------            
; 100 = TBD          c 1100 4X10      | Other specials could be used for
; 101 = TBD          d 1101 10X4      | tiles that depend on game events,
; 110 = TBD          e 1110 10X8      | or prebuilt tile structures (like
; 111 = TBD          f 1111 10X10     | a castle)
;--------------------------------------------------------------------------



; This is the tile layout for level 1 -- inside small castle
levelData1
s111
	byte $0B
s112	
	byte $0B
s113
	byte $0B
s121
	byte $0B
s122	
	byte $a0,$0a
	byte $a9
	byte $91,%00000000
	byte $18,%10000011 ; stairs
s123
	byte $0B
s131
	byte $0B
s132	
	byte $a1
	byte $59,%10000010 ; door
	byte $09,%01010000 ; 5x1 wall
	byte $69,%00011000 ; 4x1 wall
	byte $04,%01011000 ; 1x5 wall
	byte $94,%01011000 ; 1x5 wall
	byte $00,%01000111 ; 10x1 X's
s133
	byte $0B
s141
	byte $0B
s142	
	byte $a0,$a9
	byte $9a
	byte $01,%00000000
	byte $84,%00000101 ; chest
	byte $81,%00000100 ; candle
	byte $88,%00000100 ; candle
s143
	byte $0B
s151
	byte $0B
s152	
	byte $0B
s153
	byte $0B
s199


	
levelData2 ; passage under castle to isolated hut
s211
	byte $B0
s212	
	byte $B0
s213
	byte $B0
s214
	byte $B0
s215
	byte $B0
s221
	byte $B0
s222
	byte $00,%01011000 ; 1x5 wall
	byte $a0
	byte $a5
	byte $06,%01101111
	byte $11,%00000001 ; stairs
	byte $90,%01011000 ; 1x5 wall
	byte $84,%00000101 ; chest
s223
	byte $b0
s224
	byte $b0
s225
	byte $B0
s231
	byte $B0
s232
	byte $b0
s233
	byte $b0
s234
	byte $00,%00000000
s235
	byte $B0
s241
	byte $B0
s242
	byte $00,%00000000
s243
	byte $00,%00000000
s244
	byte $00,%00000000
s245
	byte $B0
s251
	byte $B0
s252
	byte $00,%00000000
s253
	byte $00,%00000000
s254
	byte $00,%00000000
s255
	byte $B0
s261
	byte $B0
s262
	byte $00,%00000000
s263
	byte $00,%00000000
s264
	byte $00,%00000000
s265
	byte $B0
s271
	byte $B0
s272
	byte $00,%00000000
s273
	byte $00,%00000000
s274
	byte $00,%00000000
s275
	byte $B0
s281
	byte $B0
s282
	byte $B0
s283
	byte $B0
s284
	byte $B0
s285
	byte $B0
s299


; This is the tile layout for level 3 -- inside a hut
levelData3
s311
	byte $0B
s312	
	byte $0B
s313
	byte $0B
s321
	byte $0B
s322	
	byte $0a
	byte $a0,$9a
	byte $81,%00000110 ; computer
	byte $69,%00011000 ; 4x1 wall
	byte $19,%00011000 ; 4x1 wall
	byte $59,%10000010 ; door
s323
	byte $0B
s331
	byte $0B
s332	
	byte $0B
s333
	byte $0B
s399



; This points to each 10x10 cell in levelData.
; Currently, this requires the level to be in one page...
; note that each row is a list of COLUMNS
scptr0
	byte <s011,<s012,<s013,<s014,<s015,<s016,<s017,<s018
	byte <s021,<s022,<s023,<s024,<s025,<s026,<s027,<s028
	byte <s031,<s032,<s033,<s034,<s035,<s036,<s037,<s038
	byte <s041,<s042,<s043,<s044,<s045,<s046,<s047,<s048
	byte <s051,<s052,<s053,<s054,<s055,<s056,<s057,<s058
	byte <s061,<s062,<s063,<s064,<s065,<s066,<s067,<s068
	byte <s071,<s072,<s073,<s074,<s075,<s076,<s077,<s078
	byte <s081,<s082,<s083,<s084,<s085,<s086,<s087,<s088
	byte <s099

scptr1
	byte <s111,<s112,<s113
	byte <s121,<s122,<s123
	byte <s131,<s132,<s133
	byte <s141,<s142,<s143
	byte <s151,<s152,<s153
	byte <s199

scptr2
	byte <s211,<s212,<s213,<s214,<s215
	byte <s221,<s222,<s223,<s224,<s225
	byte <s231,<s232,<s233,<s234,<s235
	byte <s241,<s242,<s243,<s244,<s245
	byte <s251,<s252,<s253,<s254,<s255
	byte <s261,<s262,<s263,<s264,<s265
	byte <s271,<s272,<s273,<s274,<s275
	byte <s281,<s282,<s283,<s284,<s285
	byte <s299
	
scptr3
	byte <s311,<s312,<s313
	byte <s321,<s322,<s323
	byte <s331,<s332,<s333
	byte <s399

scptr4
	byte <s411,<s412,<s413,<s414,<s415,<s416,<s417,<s418
	byte <s421,<s422,<s423,<s424,<s425,<s426,<s427,<s428
	byte <s431,<s432,<s433,<s434,<s435,<s436,<s437,<s438
	byte <s441,<s442,<s443,<s444,<s445,<s446,<s447,<s448
	byte <s451,<s452,<s453,<s454,<s455,<s456,<s457,<s458
	byte <s461,<s462,<s463,<s464,<s465,<s466,<s467,<s468
	byte <s471,<s472,<s473,<s474,<s475,<s476,<s477,<s478
	byte <s481,<s482,<s483,<s484,<s485,<s486,<s487,<s488
	byte <s499

scptr5
	byte <s511,<s512,<s513,<s514,<s515,<s516,<s517,<s518
	byte <s521,<s522,<s523,<s524,<s525,<s526,<s527,<s528
	byte <s531,<s532,<s533,<s534,<s535,<s536,<s537,<s538
	byte <s541,<s542,<s543,<s544,<s545,<s546,<s547,<s548
	byte <s551,<s552,<s553,<s554,<s555,<s556,<s557,<s558
	byte <s561,<s562,<s563,<s564,<s565,<s566,<s567,<s568
	byte <s571,<s572,<s573,<s574,<s575,<s576,<s577,<s578
	byte <s581,<s582,<s583,<s584,<s585,<s586,<s587,<s588
	byte <s599

scptr6
	byte <s611,<s612,<s613,<s614,<s615,<s616,<s617,<s618
	byte <s621,<s622,<s623,<s624,<s625,<s626,<s627,<s628
	byte <s631,<s632,<s633,<s634,<s635,<s636,<s637,<s638
	byte <s641,<s642,<s643,<s644,<s645,<s646,<s647,<s648
	byte <s651,<s652,<s653,<s654,<s655,<s656,<s657,<s658
	byte <s661,<s662,<s663,<s664,<s665,<s666,<s667,<s668
	byte <s671,<s672,<s673,<s674,<s675,<s676,<s677,<s678
	byte <s681,<s682,<s683,<s684,<s685,<s686,<s687,<s688
	byte <s699

scptr7
	byte <s711,<s712,<s713,<s714,<s715,<s716,<s717,<s718
	byte <s721,<s722,<s723,<s724,<s725,<s726,<s727,<s728
	byte <s731,<s732,<s733,<s734,<s735,<s736,<s737,<s738
	byte <s741,<s742,<s743,<s744,<s745,<s746,<s747,<s748
	byte <s751,<s752,<s753,<s754,<s755,<s756,<s757,<s758
	byte <s761,<s762,<s763,<s764,<s765,<s766,<s767,<s768
	byte <s771,<s772,<s773,<s774,<s775,<s776,<s777,<s778
	byte <s781,<s782,<s783,<s784,<s785,<s786,<s787,<s788
	byte <s799

	align 256
; This is the tile layout for level 0 -- main outside area
levelData0
s011
	byte $F0
s012	
	byte $F0
s013
	byte $F0
s014
	byte $F0
s015
	byte $F0
s016
	byte $F0
s017
	byte $F0
s018
	byte $F0

s021
	byte $F0
s022
	byte $43,%00000111
	byte $32,%10110000
	byte $01,%00010000
	byte $00,%00011000
	byte $66,%10110000
s023
	byte $00,%00100000
	byte $D4 
	byte $52,%10110000
	byte $09,%00110000
s024
	byte $F0
s025
	byte $00,%00101000
	byte $02,%00100000
	byte $20,%00011000
	byte $C2,$D5
s026
	byte $02,%00100000
	byte $D0,$D5
s027
	byte $08,%00101000
	byte $04,%00100000
	byte $29,%00011000
	byte $D0
	byte $66,%10101000
	byte $44,%00000111
s028
	byte $F0

s031
	byte $F0
s032
	byte $a0
	byte $c2
	byte $d5
	byte $41, %00011000
s033
	byte $23,%00011010
	byte $33,%00000011
	byte $20,%00000001
	byte $35,%00000001
	byte $14,%00000001
	byte $50,%10110000
	byte $c6
s034
	byte $03,%00100000
	byte $07,%00101000
	byte $D0,$D5
s035
	byte $D0,$D5
s036
	byte $D0,$D5
s037
	byte $29,%00011000
	byte $D0,$D5
s038
	byte $F0

s041
	byte $F0
s042
	byte $40, %00011000
	byte $c2
	byte $d5
s043
	byte $0c
	byte $5c
s044
	byte $54,%00110000
	byte $63,%00011000
	byte $87,%00101000
	byte $91,%00010000
s045
	byte $0c
	byte $5c
s046
	byte $33,%10110000
s047
	byte $A9
	byte $58,%00011000
	byte $33,%10110000
s048
	byte $F0
s051
	byte $F0
s052
	byte $0c
	byte $5A,$6a
	byte $40,%00010000
	byte $70,%00010000
s053
	byte $4A,$5a
	byte $60,%00010000
	byte $26,%00000111
s054
	byte $F0
s055
	byte $30,%00011000
	byte $51,%00100010
	byte $64,%00100010
	byte $68,%00010010
s056
	byte $60,%00100010
	byte $34,%00000101	; used to be the gate
	byte $66,%00100010
	byte $53,%00000010
	byte $55,%00001010
s057
	byte $60,%00011010
	byte $33,%10110000
	byte $88,%00000111
s058
	byte $F0

s061
	byte $F0
s062
	byte $0D
	byte $50,%00110000
	byte $30,%00001000
	byte $83,%00001000
	byte $35,%10110000
s063
	byte $0D
	byte $54,%00110010
	byte $76,%00000011
s064
	byte $0D,$5D
	byte $01,%00100000
	byte $05,%00100000
	byte $14,%00010000
s065
	byte $0D
	byte $60,%00100001
	byte $90,%00100001
	byte $64,%00011001
	byte $71,%00101000
	byte $51,%00010001
	byte $83,%00000111
s066
	byte $0D,$5D
s067
	byte $A9
	byte $36, %00101000
	byte $28, %00011000
	byte $40, %00100010
	byte $00, %00011010
	byte $44, %00010010
s068
	byte $F0

s071
	byte $F0
s072
	byte $F0
s073
	byte $50,%00110000
	byte $30,%00001000
	byte $83,%00001000
	byte $25,%00011111
	byte $C7
s074
	byte $0D,$5D
	byte $9A
s075
	byte $0D,$5D
	byte $01,%00010001
s076
	byte $0D,$5D
	byte $9A
	byte $83,%00010000
s077
	byte $0D
	byte $57,%00110000
	byte $39,%00001000
	byte $86,%00001000
	byte $55,%00000111
s078
	byte $F0
s081 ; was the island
;	byte $B0, $8B       ;huts?
;	byte $02, %00010000 ;water
;	byte $08, %00010000 ;water
;	byte $68, %00110000 ;water
;	byte $74, %00100000 ;water
	byte $52, %00000111 ;hut
;	byte $14, %10110000 ;water
s082
	byte $F0
s083
	byte $F0
s084
	byte $F0
s085 ; gateway to scary forest!
;	byte $50,%00100010 ; 1x4 wall
;	byte $55,%00100010 ; 1x4 wall
;	byte $39,%01010000 ; 5x1 water

	byte $00,%01000010 ; 10 wall
	byte $52,%00000011 ; door
	byte $51,%00100010 ; 1x4 wall
	byte $04,%01000010 ; 10 wall
	byte $05,%01101000 ; 4x10 water
	byte $a9
s086
	byte $F0
s087
	byte $F0
s088
	byte $F0
s099


	align 256
; This is the tile layout for level 4 -- scary forest
levelData4
s411
	byte $e5
s412	
	byte $00,%01000010 ;wall
	byte $02,%01110000
	byte $a1
s413
	byte $F0
s414
	byte $F0
s415 ; west passage to main area
	byte $00,%01000010 ; 10 wall
	byte $62,%00000011 ; door
	byte $61,%00100010 ; 1x4 wall
	byte $04,%01000010 ; 10 wall
	byte $05,%01101000 ; 4x10 water
	byte $a9
s416
	byte $F0
s417
	byte $F0
s418
	byte $F0
s421
	byte $e5
s422
	byte $00,%01000010
	byte $02,%11110000
s423
	byte $d0,$d5
s424
	byte $d0,$d5
s425
	byte $d0,$d5
s426
	byte $d0,$d5
s427
	byte $d0,$d5
s428
	byte $F0

s431
	byte $e5
s432
	byte $00,%01000010
	byte $01,%11110000
s433
	byte $d0,$d5
s434
	byte $d0,$d5
s435
	byte $d0,$d5
s436
	byte $d0,$d5
s437
	byte $d0,$d5
s438
	byte $F0

s441
;	byte $e0
	byte $49,%00000001 ; rock
	byte $69,%00000001 ; rock
s442 ; passage to mountain
	byte $00,%01000010 ; 4x1 wall
	byte $50,%00000011 ; gate
	byte $41,%00000100 ; tree
	byte $61,%00000101 ; tree
s443
	byte $d0,$d5
s444
	byte $d0,$d5
s445
	byte $d0,$d5
s446
	byte $d0,$d5
s447
	byte $d0,$d5
s448
	byte $F0
s451
	byte $e5
s452
	byte $00,%01000010
	byte $01,%11110000
s453
	byte $d0,$d5
s454
	byte $d0,$d5
s455
	byte $d0,$d5
s456
	byte $d0,$d5
s457
	byte $d0,$d5
s458 ; passage down
;	byte $04,%00011000 ; 4x1 water
;	byte $45,%01010000 ; 5x1 water
;	byte $63,%00110000 ; 4x3 water
;	byte $05,%00101000 ; 2x2 water
;	byte $02,%00101000 ; 2x2 water
	byte $02,%01101000 ; remove later
	byte $06,%01101000 ; remove later
s461
	byte $e5
s462
	byte $00,%01000010
	byte $02,%11110000
s463
	byte $d0,$d5
s464
	byte $22,%01011010 ; wall 
	byte $62,%01011010 ; wall
	byte $22,%00011010 ; wall
	byte $46,%00001010 ; wall
	byte $36,%00000110 ; gate
	byte $44,%00000111 ; hut
s465
	byte $d0,$d5
s466
	byte $d0,$d5
s467
	byte $d0,$d5
s468
	byte $F0

s471
	byte $e5
s472
	byte $00,%01000010
	byte $01,%11110000
	byte $35,%00000111
s473
	byte $d0,$d5
s474
	byte $d0,$d5
s475
	byte $d0,$d5
s476
	byte $d0,$d5
s477
	byte $d0,$d5
s478
	byte $F0
s481
	byte $e5
s482
	byte $00,%01000010 ;wall
	byte $02,%01110000
	byte $a1
s483
	byte $F0
s484
	byte $F0
s485
	byte $F0
s486
	byte $F0
s487 ; passage east...
	byte $61,%00100010 ; 1x4 wall
	byte $66,%00100010 ; 1x4 wall
	byte $40,%01010000 ; 5x1 water
	byte $65,%00000010 ; gate (remove later)
s488
	byte $F0
s499

	align 256
; This is the tile layout for level 5 -- mountain
levelData5
s511
	byte $b0
s512	
	byte $b0
s513
	byte $b0
s514
	byte $02,%01110111 ; huts
	byte $a0,$a1       ; lava
s515
	byte $b0
s516
	byte $b0
s517
	byte $b0
s518
	byte $e0           ; rocks
	byte $05,%01000010 ; wall
	byte $06,%11101000 ; trees
s521
	byte $b0
s522
	byte $e0,$0e
s523
	byte $e0,$0e
s524
	byte $02,%11110001 ; rocks
	byte $a0,$a1       ; lava
s525
	byte $e0,$0e
s526
	byte $e0,$0e
s527
	byte $E0,$E5
s528
	byte $e0           ; rocks
	byte $05,%01000010 ; wall
	byte $06,%11101000 ; trees

s531
	byte $b0
s532
	byte $e0,$0e
s533
	byte $e0,$0e
s534
	byte $02,%11110001 ; rocks
	byte $a0,$a1       ; lava
s535
	byte $e0,$0e
s536
	byte $e0,$0e
s537
	byte $e0,$e5
s538
	byte $e0           ; rocks
	byte $05,%01000010 ; wall
	byte $06,%11101000 ; trees

s541
	byte $b0
s542
	byte $e0,$0e
s543
	byte $e0,$0e
s544
	byte $02,%11110001 ; rocks
	byte $a0,$a1       ; lava
s545
	byte $e0,$0e
s546
	byte $e0,$0e
s547
	byte $e0,$0e
s548 ; to scary forest
	byte $05,%01000010 ; 4x1 wall
	byte $55,%00000011 ; gate
	byte $44,%00000001 ; rock
	byte $64,%00000001 ; rock
	byte $46,%00000100 ; tree
	byte $66,%00000101 ; tree
s551
	byte $b0
s552
	byte $e0,$0e
s553
	byte $e0,$0e
s554
	byte $02,%11110001 ; rocks
	byte $a0,$a1       ; lava
s555
	byte $e0,$0e
s556
	byte $e0,$0e
s557
	byte $e0,$0e
s558
	byte $e0           ; rocks
	byte $05,%01000010 ; wall
	byte $06,%11101000 ; trees

s561
	byte $b0
s562
	byte $e0,$0e
s563
	byte $e0,$0e
s564
	byte $02,%11110001 ; rocks
	byte $a0,$a1       ; lava
s565
	byte $e0,$0e
s566
	byte $e0,$0e
s567
	byte $e0,$0e
s568
	byte $e0           ; rocks
	byte $05,%01000010 ; wall
	byte $06,%11101000 ; trees

s571
	byte $b0
s572
	byte $e0,$0e
s573
	byte $e0,$0e
s574
	byte $02,%11110001 ; rocks
	byte $00,%01010000 ; lava
	byte $01,%01010000 ; lava
	byte $50,%00101000 ; lava
	byte $70,%00010111
	byte $90,%00010111
;	byte $a0,$a1       ; lava
s575
	byte $e0,$0e
s576
	byte $e0,$0e
s577
	byte $e0,$0e
s578
	byte $e0           ; rocks
	byte $05,%01000010 ; wall
	byte $06,%11101000 ; trees

s581
	byte $b0
s582
	byte $b0
s583
	byte $b0
s584
	byte $02,%01110111 ; wall
	byte $a0,$a1       ; lava
s585
	byte $b0
s586
	byte $b0
s587
	byte $b0
s588
	byte $e0           ; rocks
	byte $05,%01000010 ; wall
	byte $06,%11101000 ; trees
s599

	align 256
; This is the tile layout for level 6 -- ???????
levelData6
s611
	byte $B0
s612	
	byte $B0
s613
	byte $B0
s614
	byte $B0
s615
	byte $B0
s616
	byte $B0
s617
	byte $B0
s618
	byte $B0
s621
	byte $B0
s622
	byte $00,%00000000
s623
	byte $00,%00000000
s624
	byte $00,%00000000
s625
	byte $00,%00000000
s626
	byte $00,%00000000
s627
	byte $00,%00000000
s628
	byte $B0

s631
	byte $B0
s632
	byte $00,%00000000
s633
	byte $00,%00000000
s634
	byte $00,%00000000
s635
	byte $00,%00000000
s636
	byte $00,%00000000
s637
	byte $00,%00000000
s638
	byte $B0

s641
	byte $B0
s642
	byte $00,%00000000
s643
	byte $00,%00000000
s644
	byte $00,%00000000
s645
	byte $00,%00000000
s646
	byte $00,%00000000
s647
	byte $00,%00000000
s648
	byte $B0
s651
	byte $B0
s652
	byte $00,%00000000
s653
	byte $00,%00000000
s654
	byte $00,%00000000
s655
	byte $00,%00000000
s656
	byte $00,%00000000
s657
	byte $00,%00000000
s658
	byte $B0

s661
	byte $B0
s662
	byte $00,%00000000
s663
	byte $00,%00000000
s664
	byte $00,%00000000
s665
	byte $00,%00000000
s666
	byte $00,%00000000
s667
	byte $00,%00000000
s668
	byte $B0

s671
	byte $B0
s672
	byte $00,%00000000
s673
	byte $00,%00000000
s674
	byte $00,%00000000
s675
	byte $00,%00000000
s676
	byte $00,%00000000
s677
	byte $00,%00000000
s678
	byte $B0
s681
	byte $B0
s682
	byte $B0
s683
	byte $B0
s684
	byte $B0
s685
	byte $B0
s686
	byte $B0
s687
	byte $B0
s688
	byte $B0
s699

	
	align 256
; This is the tile layout for level 7 -- ???????
levelData7
s711
	byte $F0
s712	
	byte $F0
s713
	byte $F0
s714
	byte $F0
s715
	byte $F0
s716
	byte $F0
s717
	byte $F0
s718
	byte $F0
s721
	byte $F0
s722
	byte $00,%00000000
s723
	byte $00,%00000000
s724
	byte $00,%00000000
s725
	byte $00,%00000000
s726
	byte $00,%00000000
s727
	byte $00,%00000000
s728
	byte $F0

s731
	byte $F0
s732
	byte $00,%00000000
s733
	byte $00,%00000000
s734
	byte $00,%00000000
s735
	byte $00,%00000000
s736
	byte $00,%00000000
s737
	byte $00,%00000000
s738
	byte $F0

s741
	byte $F0
s742
	byte $00,%00000000
s743
	byte $00,%00000000
s744
	byte $00,%00000000
s745
	byte $00,%00000000
s746
	byte $00,%00000000
s747
	byte $00,%00000000
s748
	byte $F0
s751
	byte $F0
s752
	byte $00,%00000000
s753
	byte $00,%00000000
s754
	byte $00,%00000000
s755
	byte $00,%00000000
s756
	byte $00,%00000000
s757
	byte $00,%00000000
s758
	byte $F0

s761
	byte $F0
s762
	byte $00,%00000000
s763
	byte $00,%00000000
s764
	byte $00,%00000000
s765
	byte $00,%00000000
s766
	byte $00,%00000000
s767
	byte $00,%00000000
s768
	byte $F0

s771
	byte $F0
s772
	byte $00,%00000000
s773
	byte $00,%00000000
s774
	byte $00,%00000000
s775
	byte $00,%00000000
s776
	byte $00,%00000000
s777
	byte $00,%00000000
s778
	byte $F0
s781
	byte $F0
s782
	byte $F0
s783
	byte $F0
s784
	byte $F0
s785
	byte $F0
s786
	byte $F0
s787
	byte $F0
s788
	byte $F0
s799


	include chardisp.asm
	include chardata.h


;==========================================================================
; Inventory Display Caller
;==========================================================================
	org $2Fc3
	rorg $1fc3
	jmp invDisp
rtnInvDisp
	stx BANK1

;==========================================================================
; Special Check Caller
;==========================================================================
	org $2Fd3
	rorg $1fd3
	jmp specialCheck
rtnSpecialCheck
	stx BANK1

;==========================================================================
; Level Get caller
;==========================================================================
	org $2Fe3
	rorg $1fe3
	jmp getLevel
rtnGetLevel
	stx BANK1

;==========================================================================
; The cart may start up in this bank.  Make sure it switches
; back to bank 1 on startup.
;==========================================================================
	org $2FED
	rorg $1FED
b2Startup
	sta BANK1
	org $2FFC
	rorg $1FFC	; Program startup vector
	word b2Startup
	word b2Startup
