;---------------------------------------------------------------------------
;
; Homestar Runner RPG
;
;---------------------------------------------------------------------------
; TEXT EDITOR: TAB=3
;---------------------------------------------------------------------------

	processor 6502	
	include vcs.h	


;===========================================================================
; RAM Variables
;===========================================================================

;---------------------------------
; levelDataA - tile graphics
;---------------------------------
levelDataA	equ $80 ;-$B1 (50 bytes)

;================================;
; this area used for map display	;
; (tile buffer) or map loading	;
; (temp variable and (cmdBuf)		;
;================================;
;temp storage for map display    ;
grfxBuffer	equ $B2;-C5 20 bytes ;
;--------------------------------;
;temp storage for map loading    ;
temp3			equ $B2					;
startX		equ $B3					;
startY		equ $B4					;
width			equ $B5					;
height		equ $B6					;
tile			equ $B7					;
cmdBuf		equ $B8;-C5 14 bytes ;
;================================;
;temp for joystick/map handling  ;
tempX			equ $B2					;
tempY			equ $B3					;
saveX			equ $B4					;
specResult	equ $B5					;
specChkSet	equ $B6
;================================;

;================================;
; $C6 used for general temp or	;
; linecolor during the kernal		;
;================================;
temp4			equ $C6 					;
;--------------------------------;
linecolor	equ $C6 ;kernal		;
;================================;

temp 			equ $C7	;
temp2			equ $C8	;

frame 		equ $C9	; frame counter

locX			equ $CA	; player's X location on map
locY			equ $CB	; player's Y location on map

flag			equ $CC  ; 7=skip vblank 6=joystick debouncing 5=map transport pending

FLAG_SKIP_VBLANK 			equ %10000000
FLAG_JOYSTICK_DEBOUNCE 	equ %01000000
FLAG_MAP_TRANSPORT 		equ %00100000

backChar		equ $CD	; really only requires 4 bits usage, and can be temp for kernal

mode			equ $CE	; main mode control
mode_cnt		equ $CF	; main mode counter

bkcolor		equ $D0 	; level background color, can probably be removed later by considering the background color part of the color set

tileSet		equ $D2	; current tile/color set (determined by map)

location 	equ $E0	; current map
randH			equ $E1	; TEMP


; other - 22 bytes - $D1-E6
; general game control
;  8 bytes
; monster history
;  8 bytes
; monster tracking/status
;  6 bytes

; character stats $E7-FB
;  21 bytes = 35 character save2 code   1 A W 8 S  3 O P 4 R
; 0 strength/speed
; 1 nerdiness/awesomeness
; 2 experience L (x2 and only use 14 bits?)
; 3 experience H
; 4 magic 1 (spells learned 1-8)
; 5 magic 2 (spells learned 9-16)
; 6 magic 3 (magic points: lev1 0-7, lev2 0-7, lev3 0-4)
; 7 gold (probably want two bytes for this, maybe share with EXP?, or magic 2?)
; 8 item 1 - each item = 6 bits (64 items) + 1 action (equipped/activated) bit + 1 game completion bit
; 9 item 2   (need weapon, armor, shei
; 10 item 3
; 11 item 4
; 12 item 5
; 13 item 6
; 14 item 7
; 15 item 8
; 16 item 9
; 17 item 10
; 18 item 11
; 19 melonade/arrows?
; 20 special items / game completion
; 21 location (only need 4 bits here -- won't be more than 16 save locations)


;stack = $FC-$FF   4 bytes, can probably be reduced to 2 eventually

;===========================================================================
; Constants
;===========================================================================

;BANK1 equ $1ff6 ;16K
;BANK2 equ $1ff7
;BANK3 equ $1ff8
;BANK4 equ $1ff9

TILE_NOTHING equ 0		; | special tile search results
TILE_TRANSPORT equ 1		; |

PIGSFLY equ 0

BANK1 equ $1ff8 ;8K
BANK2 equ $1ff9
BANK3 equ 0
BANK4 equ 0

TOPBLANKTIME equ 21		; Time x 64 cycles of blank area above map

PLAYERCOLOR equ $08		; Color of player graphics/map

VBLANKOVERSCANTIME equ 17

;STARTPOSX equ $25;$63
;STARTPOSY equ $25;$38
STARTPOSX equ $13
STARTPOSY equ $12
STARTLEV equ 0

MANOFFSET equ 22 			; Where the players character is placed on the map

MAPSIZEX equ $70
MAPSIZEY equ $70

EXTRALINES equ 29

;---------------------------------
; Mode definitions / counter settings
;---------------------------------
M_MAP		equ 8	; display map normally

M_LOAD	equ 9	; load map

M_STATUS equ 10; show inventory/status screen

M_SCRL	equ 0 ; scroll left
M_SCRR	equ 1	; scroll right
M_SCRU	equ 2	; scroll up
M_SCRD	equ 3	; scroll down

M_SCRLS	equ 4 ; scroll left special
M_SCRRS	equ 5 ; (unused)
M_SCRUS	equ 6	; scroll up special
M_SCRDS	equ 7 ; (unused)

SCROLL_MASK equ %11111000 ; mask to check for any scroll mode

; Mode Timing: number of frames
C_LOAD	equ 11
C_SCR		equ 2 ; scroll count

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
	org $1000
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------

	; Swaps high and low nibble of a byte
swap
	byte $00,$10,$20,$30, $40,$50,$60,$70, $80,$90,$a0,$b0, $c0,$d0,$e0,$f0
	byte $01,$11,$21,$31, $41,$51,$61,$71, $81,$91,$a1,$b1, $c1,$d1,$e1,$f1
	byte $02,$12,$22,$32, $42,$52,$62,$72, $82,$92,$a2,$b2, $c2,$d2,$e2,$f2
	byte $03,$13,$23,$33, $43,$53,$63,$73, $83,$93,$a3,$b3, $c3,$d3,$e3,$f3
	byte $04,$14,$24,$34, $44,$54,$64,$74, $84,$94,$a4,$b4, $c4,$d4,$e4,$f4
	byte $05,$15,$25,$35, $45,$55,$65,$75, $85,$95,$a5,$b5, $c5,$d5,$e5,$f5
	byte $06,$16,$26,$36, $46,$56,$66,$76, $86,$96,$a6,$b6, $c6,$d6,$e6,$f6
	byte $07,$17,$27,$37, $47,$57,$67,$77, $87,$97,$a7,$b7, $c7,$d7,$e7,$f7
	byte $08,$18,$28,$38, $48,$58,$68,$78, $88,$98,$a8,$b8, $c8,$d8,$e8,$f8
	byte $09,$19,$29,$39, $49,$59,$69,$79, $89,$99,$a9,$b9, $c9,$d9,$e9,$f9
	byte $0a,$1a,$2a,$3a, $4a,$5a,$6a,$7a, $8a,$9a,$aa,$ba, $ca,$da,$ea,$fa
	byte $0b,$1b,$2b,$3b, $4b,$5b,$6b,$7b, $8b,$9b,$ab,$bb, $cb,$db,$eb,$fb
	byte $0c,$1c,$2c,$3c, $4c,$5c,$6c,$7c, $8c,$9c,$ac,$bc, $cc,$dc,$ec,$fc
	byte $0d,$1d,$2d,$3d, $4d,$5d,$6d,$7d, $8d,$9d,$ad,$bd, $cd,$dd,$ed,$fd
	byte $0e,$1e,$2e,$3e, $4e,$5e,$6e,$7e, $8e,$9e,$ae,$be, $ce,$de,$ee,$fe
	byte $0f,$1f,$2f,$3f, $4f,$5f,$6f,$7f, $8f,$9f,$af,$bf, $cf,$df,$ef,$ff

	; This data allows for very quick playfield shading of tile data
pf0shading
	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0
	byte $3C,$FF,$3C,$FF, $3C,$3C,$FF,$FF, $3C,$3C,$3C,$3C, $FF,$FF,$3C,$3C
	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0
	byte $3C,$FF,$3C,$FF, $3C,$3C,$FF,$FF, $3C,$3C,$3C,$3C, $FF,$FF,$3C,$3C

	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0
	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0
	byte $3C,$FF,$3C,$FF, $3C,$3C,$FF,$FF, $3C,$3C,$3C,$3C, $FF,$FF,$3C,$3C
	byte $3C,$FF,$3C,$FF, $3C,$3C,$FF,$FF, $3C,$3C,$3C,$3C, $FF,$FF,$3C,$3C

	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0
	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0
	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0
	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0

	byte $3C,$FF,$3C,$FF, $3C,$3C,$FF,$FF, $3C,$3C,$3C,$3C, $FF,$FF,$3C,$3C
	byte $3C,$FF,$3C,$FF, $3C,$3C,$FF,$FF, $3C,$3C,$3C,$3C, $FF,$FF,$3C,$3C
	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0
	byte 0,$C3,0,$C3, 0,0,$C3,$C3, 0,0,0,0, $C3,$C3,0,0

	; This data allows the pf color for a given line of tiles to be quickly determined
	; color set 1: 1&3=water=$00, 6&7=wall=$10, C&D=rock=$08
pfcolors
	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0
	byte $00,$00,$00,$00, $00,$00,$00,$00, $00,$00,$00,$00, $00,$00,$00,$00
	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0
	byte $00,$00,$00,$00, $00,$00,$00,$00, $00,$00,$00,$00, $00,$00,$00,$00

	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0
	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0
	byte $10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10
	byte $10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10,$10

	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0
	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0
	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0
	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0

	byte $08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08
	byte $08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08
	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0
	byte 0,$00,0,$00, 0,0,$10,$10, 0,0,0,0, $08,$08,0,0


;---------------------------------------------------------------------------
; println
;---------------------------------------------------------------------------
; New version of David Cranes pseudo-interlacing text routine 
; from Stellar Track/Basic Programming.  This version is centered,
; only displays 10 characters, and also includes code to display 
; playfield graphics to add color.  It is divided into
; two separate routines, one for even and one for odd frames.
;---------------------------------------------------------------------------
; grfxBuffer offsets
; x     x     x     x     x
;00 02 04 06 08 10 12 14 16 18
; A  B  C  D  E  F  G  H  I  J
;    x     x     x     x     x
;---------------------------------------------------------------------------
println
	sec

	ldy #$B0						;2

	lax (grfxBuffer + 18),y	;5

	lda frame
	and #1
	beq noShift

	lax (grfxBuffer + 16),y	;5

	lda #$80
	sta HMP0
	sta HMP1

	sta WSYNC
	sta HMOVE
	sta HMCLR
	jmp frameB

	bne frameA
noShift
	sta WSYNC
	sta HMCLR
	sta $2D

frameA ;@3
	stx.w GRP0					;3
	jmp enterA

loopA ;@21
	lda (grfxBuffer + 18),y	;5 @3
	sta GRP0						;3
enterA
	lda (grfxBuffer + 14),y	;5
	sta.w GRP1					;3

	sta HMCLR

	ldx linecolor				;3 @30

	lda (grfxBuffer + 10),y	;5
	stx COLUPF					;3
	
	sta.w GRP0					;3
	lda (grfxBuffer + 6),y	;5
	sta GRP1						;3 @49

	lda (grfxBuffer + 2),y	;5
	sta GRP0						;3
	lda bkcolor					;3 @59
	sta COLUPF					;3 @66

	ldx #$80						;2
	stx HMP0						;3 
	stx HMP1						;3 @72

	tya							;2
	sbc #$10
	tay

	sta HMOVE					;3 @3

	;--------------------------

	lda (grfxBuffer + 16),y	;5
	sta GRP0						;3
	lda (grfxBuffer + 12),y	;5
	sta.w GRP1					;3 @20

	nop							;2
	nop							;2

	ldx.w linecolor			;3 @30
	lda (grfxBuffer + 8),y	;5
	stx COLUPF					;3
	ldx #$80						;2
	sta GRP0						;3
	lda (grfxBuffer + 4),y	;5
	sta GRP1						;3 @49

	lda (grfxBuffer + 0),y	;5
	sta GRP0						;3
	lda bkcolor					;2 @59
	sta COLUPF					;3 @66
	sta HMCLR					;3 
	stx HMM0
	tya
	sta HMOVE					;3 @74
	sbc #$10
	;-------------------------
	tay
	bcs loopA					;2/3

quitA
	lda #0
	sta GRP0
	sta GRP1
	rts	

	;====================================
	;====================================
	;====================================

frameB ;@7
	lda (grfxBuffer + 12),y	;5
	sta GRP1						;3
	stx GRP0						;3
	nop
	nop
	;sta $2D
;	dec $2D						;5 delay
loopB ;@24
	ldx linecolor				;3 @27

	lda (grfxBuffer + 8),y	;5
	stx.w COLUPF				;3
	ldx #$80						;2
	sta GRP0						;3
	lda (grfxBuffer + 4),y	;5
	sta GRP1						;3 @46

	lda (grfxBuffer + 0),y	;5
	sta GRP0						;3
	lda bkcolor					;2 @56
	sta COLUPF					;3 @63
	stx HMCLR					;3 
	stx HMM0						;3
	tya							;2
	sta HMOVE					;3 @74

	;--------------------------
	sta HMCLR
	sbc #$10						;2 @0
	tay
	lda (grfxBuffer + 18),y	;5
	sta.w GRP0						;3
	lda (grfxBuffer + 14),y	;5
	sta GRP1						;3 @21

	stx HMP0						;4

	ldx linecolor				;3 @30
	lda (grfxBuffer + 10),y	;5
	stx COLUPF					;3
	sta GRP0						;3
	lda (grfxBuffer + 6),y	;5
	sta GRP1						;3 @51

	lda (grfxBuffer + 2),y	;5
	sta GRP0						;3
	lda bkcolor					;2 @61
	sta.w COLUPF				;3 @66
	ldx #$80						;2
	tya
	sbc #$10						;2

	bcc quitB					;2/3
	stx HMP1						;3 @69
	
	sta WSYNC					;3 @0
	sta HMOVE					;3 @3

	tay

	lda (grfxBuffer + 16),y	;5
	sta GRP0						;3
	lda (grfxBuffer + 12),y	;5
	sta GRP1						;3 @19

	jmp loopB
	bpl loopB					;2/3

quitB
	sta WSYNC
	jmp quitA



	align 256
	; Tile data (160 bytes)
charData1
	include tiles1.h

				
;---------------------------------------------------------------------------
; Start of Program
;---------------------------------------------------------------------------
; Clear memory, locate character graphics positions and such,
; initialize key memory values, start GameLoop.
;---------------------------------------------------------------------------
StartB
	sei  	
	cld  		
	ldx #$FF
	txs  		
	lda #0
clearB   
	sta 0,x
	dex
	bne clearB

;---------------------------------------------------------------------------
; Initialize variables / registers
;---------------------------------------------------------------------------

	; Set players to grey
	lda #PLAYERCOLOR
	sta COLUP0
	sta COLUP1

	lda #STARTLEV
	sta location
	lda #STARTPOSX
	sta locX
	lda #STARTPOSY
	sta locY
	
	lda #M_LOAD
	sta mode
	lda #C_LOAD
	sta mode_cnt

	jsr TextSetup

	;-----------------------------------------------------
	;the entire font is limited to one page, so we can hard code that page
	;value into the MSB position of our graphics buffer
	;-----------------------------------------------------
	ldx #23         ;graphics buffer is 24 bytes
	lda #>charData1   ;load up the page value for the font
grOff
	sta grfxBuffer,x        ;stuff it, won't ever change
	dex             ;back up two bytes
	dex
	bpl grOff       ;and loop

	lda #0
	sta CTRLPF

;==========================================================================
;==========================================================================
; Main Game Loop
;==========================================================================
;==========================================================================
GameLoopB
	lda flag ; skip VSync and VBlank if we're drawing the map
	bmi rtnVBlank

	jmp VSyncB 	;start vertical retrace
rtnVSync

	jmp VBlankB    	; spare time during screen blank
rtnVBlank

	inc frame	;count frame

	; choose kernal to run based on mode
	lda mode
	cmp #M_LOAD
	bne nextKernalA
	jmp mapLoadKernal	; blank screen while loading map data
nextKernalA
	cmp #M_STATUS
	bne nextKernalB
	jmp callInvDisp	; status/inventory display
nextKernalB
	jmp mapKernal		; default to map
rtnKernal

	jmp overscanB	; do overscan
rtnOverscan

	jmp GameLoopB    ;back to top


;--------------------------------------------------------------------------
; mapLoader
;--------------------------------------------------------------------------
; Fully loads the current 10x10 location into
; the tile buffer.  This takes too much time to do during
; VBlank or overscan, so the screen is blanked during this load.
; This runs during what would normally draw the TV picture.
; The load takes 11 frames.  It loads the full screen simply
; by clearing the screen and then using the scroll load 10 times
; to load the whole pictures.
;--------------------------------------------------------------------------
mapLoadKernal
	lda INTIM			;check timer for end of VBLANK period
	bne mapLoadKernal	;loop until it reaches 0

	lda #$80
	sta WSYNC
	sta VBLANK  	;end screen blank

	; Wait through the visible picture and overscan
	lda #VBLANKOVERSCANTIME
	sta T1024T

	ldx #7
aFewLines
	sta WSYNC
	lda mode_cnt
;	sta COLUPF
;	sta PF0
;	sta PF1
;	sta PF2
	dex
	bne aFewLines
	lda #0
	sta COLUPF


	dec mode_cnt
	ldy mode_cnt

	cpy #10
	bne noClear
	lda #$00
	ldx #50
CopyLoop
	sta levelDataA,x
	dex
	bpl CopyLoop

	sed
	lda locY
	clc
	adc #$10
	sta locY
	cld

	jmp loadMore

noClear

	lda #M_SCRU
	sta mode

	sed
	lda locY
	sec
	sbc #$01
	sta locY
	cld

	ldy #0
	jsr loadRoom
	ldy #1
	jsr loadRoom

	lda #M_LOAD
	sta mode


	lda mode_cnt
	bne loadMore	
	lda #M_MAP
	sta mode
	jmp endMapLoop
loadMore

	ldy #44
sDnLoop2
	lda levelDataA,y
	sta levelDataA+5,y
	dey
	bpl sDnLoop2

	lda #0
	sta levelDataA
	sta levelDataA+1
	sta levelDataA+2
	sta levelDataA+3
	sta levelDataA+4
	;jsr scrollDown

endMapLoop
	lda INTIM	;check timer for end of VBLANK period
	bne endMapLoop	;loop until it reaches 0

	ldx #9
aFewMore
	sta WSYNC
	dex
	bne aFewMore

	jmp GameLoopB


;--------------------------------------
; TextSetup
;--------------------------------------
; use cycle counting to get the GRP 
; registers configured and located
; in exactly the right spot
;--------------------------------------
TextSetup
	sta WSYNC       ;newline
	sta RESM1
	lda #$36        ;triple copy sprites, spaced wide
	sta NUSIZ0      ;for both player graphic registers
	lda #$32
	sta NUSIZ1
	lda #%01000000
	sta HMM0
	nop
	nop
	sta temp
	sta $2D
	sta $2D
	sta RESP0
	lda #$F0
	sta RESP1
	sta HMP0
	lda #$E0
	sta HMP1
	dec $2D
	dec $2D
	nop
	nop
	
	sta RESM0

	sta WSYNC       ;newline
	sta HMOVE       ;anchor them down
	rts



;--------------------------------------------------------------------------
; VSync
;--------------------------------------------------------------------------
VSyncB
	lda #$02
	sta WSYNC	; End last scanline
	sta VBLANK
	lda #2		;bit 1 needs to be 1 to start retrace
	sta VSYNC	;start retrace
	sta WSYNC 	;wait a few lines
	sta WSYNC 
	lda #44		;prepare timer to exit blank period (44)
	sta TIM64T	;turn it on
	sta WSYNC 	;wait one more
	sta VSYNC 	;done with retrace, write 0 to bit 1

	jmp rtnVSync ; VSync





roomX10
	byte 0,$10,0,$10
roomY10
	byte 0,0,$10,$10


;--------------------------------------------------------------------------
; loadRoom
;--------------------------------------------------------------------------
; The program's scrolling map works by shifting all the tiles on
; the screen to clear one strip, then only the empty strip is filled
; from the map definition.  loadRoom decompresses one map cell
; into the strip that is currently being constructed.  Which strip 
; (top,bottom,left,or right) is determined by the current value of the 
; mode variable.  A strip is usually made up of two room cells, so this
; function is called twice (over two frames) to build a strip each time
; the map scrolls.
;
; Set Y to screen cell (0-3) before loadRoom is called.
; Set mode to scroll direction (M_SCRL,M_SCRR,M_SCRU,M_SCRD)
;
; Note that this function uses the stack pointer and assumes that the
; JSR was called with nothing on the stack.
;--------------------------------------------------------------------------

	; - temp variable usage -
	; temp  = used once for general temp storage
	; temp2 = screen cell (0-3)
	; temp3 = position in command set
	; temp4 = last display command in set (can easily be removed)

loadRoom
	sty temp2	; save cell #

	; call routine in another bank to load room
	; definition codes into cmdBuf.
	jmp callLevelGet
rtnCallLevelGet

	; set cmd pointer to first command
	ldx #0
	
	;-------------------------------
	; Process level definition codes
	;
	; Main Loop for processing codes
tileLoop

	sed
	; Calculate Y position (startY)
	lda locY
	and #$0F
	sta temp3	; locY low
	lda cmdBuf,x
	and #$0F
	cmp #$0A	; check for onebyte setup
	bmi skipOneByteA
	lda #0
skipOneByteA	
	sec
	sbc temp3	; locY low
	ldy temp2
	clc
	adc roomY10,y
	sta startY
	stx temp3

	; Check for 1 byte command
	;
	; $A-F in the high or low nibble of first byte
	; in a command indicates that it's a one bye command
	lda cmdBuf,x
	tay
	and #$0F
	cmp #$0A
	bpl oneByteL
	tya
	clc
	adc #$00
	bcs oneByteH
	bcc twoByte

	; set up the tile, width and height for
	; a one byte command
oneByteL
	tya
	and #$0F
	sec
	sbc #$0A
	tay
	lda oneByteTile,y
	sta tile
	lda oneByteSize,y
	sta width
	lda #10
	sta height
	jmp fromOneByte

	; set up the tile, width and height for
	; a one byte command
oneByteH	
	lda swap,y
	and #$0F
	sec
	sbc #10
	tay
	lda oneByteTile,y
	sta tile
	lda #10
	sta width
	lda oneByteSize,y
	sta height
	jmp fromOneByte

	; interpret a two-byte command
twoByte
	inc temp3

	; Get current tile
	lda cmdBuf+1,x
	and #%10000111
	bpl notSpecial ; bit 7 indicates if it's a special

	; Handle Special Tiles (random trees/rocks, waterB, rockB)
	; 
	eor #%10001000 ; remove special indicator bit (7) and add in bit 3 to offset in tile table

;	and #1			; determine type of special (tree or rock)
;	beq randTree
;	lda #%10111011 ; random rocks tile code
;	byte $2C ; BIT absolute -- skip next two bytes
;randTree
;	lda #%10011001 ; random trees tile code
;	sta tile
;	bne fromSpecial

notSpecial
	tay
	lda tileType,y
	sta tile

fromSpecial

	; Set up block size (width and height)
	lda cmdBuf+1,x
	lsr
	lsr
	lsr
	and #$0F
	tay
	lda blockX,y
	sta width
	lda blockY,y
	sta height

fromOneByte

	; Now calculate X position	(startX)
	lda locX
	and #$0F
	sta temp ;temp3
	ldy cmdBuf,x
	lda swap,y
	and #$0F
	cmp #$0A	; check for onebyte setup
	bmi skipOneByteB
	lda #0
skipOneByteB
	sec
	sbc temp ;temp3
	ldx temp2
	clc
	adc roomX10,x
	; save tile def pointer
	sta startX
	clc
	adc width
	sta width

	sed

	; -------------------------
	; Set up variables to fill
	; the correct strip of tiles
	; based on the current
	; scrolling direction
	; -------------------------
	lda mode
	and #%00000011
	cmp #M_SCRL
	beq leftScr 
	cmp #M_SCRR
	beq rightScr
	cmp #M_SCRU
	beq upScr
	cmp #M_SCRD
	beq downScr
	jmp yLoop

leftScr
	lda startX
	cmp #10
	bpl goSkip
	lda width
	cmp #10
	bmi goSkip
	ldx #9
	stx startX
	lda #$10
	sta width
	bne xLoop

rightScr
	lda startX
	cmp #1
	bpl goSkip
	lda width
	cmp #1
	bmi goSkip
	ldx #0
	stx startX
	lda #1
	sta width
	bne xLoop

upScr
	lda startY
	cmp #1
	bpl goSkip
	clc
	adc height
	cmp #1
	bmi goSkip
	ldy #0
	sty startY
	lda #1
	sta height
	bne yLoop
			
downScr
	lda startY
	cmp #$10
	bpl goSkip
	clc
	adc height
	cmp #$10
	bmi goSkip
	ldy #9
	sty startY
	lda #1
	sta height
	bne yLoop

goSkip
	ldy #$88
	; Make sure we're not almost out of time
	lda INTIM
	sbc #VBLANKMARGIN
	bmi pictureLoop2
	jmp skipBlock

; how close it's allowed to get to running out of time before it
; stops and waits for VBLANK
VBLANKMARGIN equ 6
			
	; ------------------------------------------------
	; Almost to the end of VBlank, go ahead and end it
	; And start using the blank area at the top of the
	; screen before the map area.
pictureLoop2
	lda INTIM	;check timer for end of VBLANK period
	bne pictureLoop2	;loop until it reaches 0

	lda #$02
	sta WSYNC	; End last scanline
	sta VBLANK
	lda #2		;bit 1 needs to be 1 to start retrace
	sta VSYNC	;start retrace
	sta WSYNC 	;wait a few lines
	sta WSYNC 
	lda #44		;prepare timer to exit blank period (44)
	sta TIM64T	;turn it on
	sta WSYNC 	;wait one more
	sta VSYNC 	;done with retrace, write 0 to bit 1

	lda #%10000000
	ora flag ; set skip vblank flag
	sta flag

	cpy #$88
	bne backFromVBlank
	jmp skipBlock
			
	;---------------------------
	; Main loop for filling area
yLoop
	ldx startX
xLoop
	ldy startY

	; Make sure we're not almost out of time
	lda INTIM
	sbc #VBLANKMARGIN
	bmi pictureLoop2
backFromVBlank

	; ------------------------
	; Check for out of range
	tya
	and #$F0
	bne skipChar2
	txa
	cmp #$10
	bpl skipChar2
	and #$F0
	bne skipChar

	; determine RAM map data offset
	; for current tile from X and Y
	; and store in Y
	lda XPosition,x
	cld
	clc
	adc YPosition,y
	sed
	tay

	; Check for a randomized tile
	lda tile
	bpl notRandomTile
	and #%01000000	
	bne notRandomTile

	; Randomize 
	; (note CLC's shouldn't be necessary here as long as the
	;  maps don't get too big: less than $F0 X $F0 )
	txs ; save X
	txa
	adc locX
	asl
	asl
;	ldx locX ; save locX in X
	sta temp ; temporarily save sum in locX

	ora #$F4	; set high byte of data offset
	sta randH 

	lda locY
	adc startY
	adc temp ; add sum from locX
;	adc tile
	sty temp
	tay
	
;	lda $F400,y ; use game data for randomization
	lda (location),y
	ldy temp
;	stx locX ; restore locX
	tsx ; restore X

	; Choose to draw tree A or tree B
	lsr
	and #%00000001
	beq fromRandom
;	bpl fromRandom
	bcs drawTreeB

drawTreeA
	txa
	lsr
	lda tile ; select tree/rock
	eor #$CC
	bcc highNib3
	and #$F0
	byte $2C
highNib3
	and #$0F
	jmp fromRandom

drawTreeB
;	tsx
	txa
	lsr
	lda tile	; select tree/rock
	eor #$DD
	bcc highNib4
	and #$F0
	byte $2C
highNib4
	and #$0F
	jmp fromRandom
	
notRandomTile
	; Choose whether to use high or low nibble of tile
	txa
	and #1
	beq highNib2
	lda #$F0
	byte $2C ; BIT absolute -- skip next two bytes
highNib2
	lda #$0F
lowNib2
	and tile

fromRandom
	ora levelDataA,y	; OR new tile data with current tile
	sta levelDataA,y	; save it

skipChar

	; finish up X loop
	txa
	clc
	adc #1
	tax
	cpx width
	beq skipChar2 
	jmp xLoop
skipChar2

	; finish up Y loop
	lda startY
	clc
	adc #1
	sta startY
	dec height
	beq stopYLoop
	jmp yLoop	
stopYLoop

	;---------------------------
	; See if there are any more 
	; map command blocks to process
skipBlock
	ldx temp3
	inx
	cpx temp4
	beq quitLoopB
	jmp tileLoop
quitLoopB

	cld

	ldx #253
	txs

	rts


;--------------------------------------------------------------------------
; scrollDown (move all tiles up)
;--------------------------------------------------------------------------
scrollDown
	ldy #44
sDnLoop
	lda levelDataA,y
	sta levelDataA+5,y
	dey
	bpl sDnLoop

	lda #0
	sta levelDataA
	sta levelDataA+1
	sta levelDataA+2
	sta levelDataA+3
	sta levelDataA+4

	jmp rtnScroll
	rts

;--------------------------------------------------------------------------
; scrollUp (move all tiles down)
;--------------------------------------------------------------------------
scrollUp
	ldy #0
sUpLoop
	lda levelDataA+5,y
	sta levelDataA,y
	iny
	cpy #45
	bne sUpLoop

	lda #0
	sta levelDataA+45
	sta levelDataA+46
	sta levelDataA+47
	sta levelDataA+48
	sta levelDataA+49
	jmp rtnScroll
	rts


;--------------------------------------------------------------------------
; scrollRight (move all tiles left)
;--------------------------------------------------------------------------
scrollRight
	lda #45
	sec
shiftLLoop
	tay
	
	lda levelDataA+4,y
	and #$F0
	sta temp
	ldx levelDataA,y
	lda swap,x				;4
	and #$0F
	ora temp
	sta levelDataA+4,y

	lda swap,x
	and #$F0
	sta temp
	ldx levelDataA+1,y
	lda swap,x				;4
	and #$0F
	ora temp
	sta levelDataA,y

	lda swap,x
	and #$F0
	sta temp
	ldx levelDataA+2,y
	lda swap,x				;4
	and #$0F
	ora temp
	sta levelDataA+1,y

	lda swap,x
	and #$F0
	sta temp
	ldx levelDataA+3,y
	lda swap,x				;4
	and #$0F
	ora temp
	sta levelDataA+2,y

	lda swap,x
	and #$F0
	sta temp
	ldx levelDataA+4,y
	lda swap,x
	and #$0F
	ora temp
	sta levelDataA+3,y

	tya
	sbc #5
	bcs shiftLLoop

	ldy #9
	lda #0
	sec
clearSideR
	ldx YPosition,y
	lda levelDataA+4,x
	and #$0F
	sta levelDataA+4,x
	dey
	bpl clearSideR
	jmp rtnScroll

	rts

;--------------------------------------------------------------------------
; scrollLeft (move all tiles right)
;--------------------------------------------------------------------------
scrollLeft

	lda #45
	sec
shiftRLoop
	tay
	
	lda levelDataA+4,y
	and #$0F
	sta temp
	ldx levelDataA+3,y
	lda swap,x
	and #$F0
	ora temp
	sta levelDataA+4,y

	lda swap,x
	and #$0F
	sta temp
	ldx levelDataA+2,y
	lda swap,x
	and #$F0
	ora temp
	sta levelDataA+3,y

	lda swap,x
	and #$0F
	sta temp
	ldx levelDataA+1,y
	lda swap,x
	and #$F0
	ora temp
	sta levelDataA+2,y

	lda swap,x
	and #$0F
	sta temp
	ldx levelDataA,y
	lda swap,x
	and #$F0
	ora temp
	sta levelDataA+1,y

	lda swap,x
	and #$0F
	sta temp
	ldx levelDataA+4,y
	lda swap,x
	and #$F0
	ora temp
	sta levelDataA,y

	tya
	sbc #5
	bcs shiftRLoop

	ldy #9
	lda #0
	sec
clearSideL
	ldx YPosition,y
	lda levelDataA+4,x
	and #$F0
	sta levelDataA+4,x
	dey
	bpl clearSideL
	jmp rtnScroll
	

	rts
	
	


;--------------------------------------------------------------------------
; Overscan
;--------------------------------------------------------------------------
; More Game Logic
;--------------------------------------------------------------------------
overscanB

	sta WSYNC	

	lda #36		; Use the timer to make sure overscan takes (34)
	sta TIM64T	; 30 scan lines.  29 scan lines * 76 = 2204 / 64 = 34.4

	; Erase your character
	lda backChar
	sta levelDataA+MANOFFSET

	lda #%01111111
	and flag ; reset skip vblank flag
	sta flag

	; See if a map transport is pending...
	lda mode
	cmp #M_MAP
	bne noReload
	lax flag
	and #FLAG_MAP_TRANSPORT
	beq noReload
	txa
	and #~FLAG_MAP_TRANSPORT
	sta flag
	lda locX
	sta tempX
	lda locY
	sta tempY
	lda #1
	sta specChkSet ; here, we want it to actually set a new map location
	jsr callSpecialCheck ; call special check in map data bank
	jmp endOSB
noReload

	;-------------------------------------------------
	; Calls to loadRoom
	;-------------------------------------------------
	; Check if we're scrolling...
	lax mode
	and #SCROLL_MASK
	bne noScrollLoad
	; then load new strip of tiles.
	txa
	and #~SCROLL_MASK
;	and #%00000111
	tax
	dec mode_cnt
	beq L2
	ldy scrollScreenA,x
	jsr loadRoom
	jmp skipOS
L2
	ldy scrollScreenB,x
	jsr loadRoom
	lda #M_MAP
	sta mode
	jmp skipOS
noScrollLoad
	;-------------------------------------------------


	; Only do overscan processing
	; if in MAP mode.
	lda mode
	cmp #M_MAP
	beq goOS
	jmp endOSB
goOS


	; *********************
	; Joystick Handling
	; *********************

joystick
	lda SWCHA
	lsr
	lsr
	lsr
	lsr
	eor #%00001111
	beq endJoy ; no direction pressed, so quit joystick section
	tax

	lda joyDir,x ; get joystick direction
	tax

	sed
	lda locX
	clc
	adc xMov,x
	sta tempX ; save potential new X position
	lda locY
	clc
	adc yMov,x
	sta tempY ; save potential new Y position
	cld

	; Check for special events if the character moved
;	lda mode
;	and #SCROLL_MASK
;	bne skipSpecialCheck ; if didn't move, no need to check

	stx saveX
	lda #0
	sta specChkSet ; on this call, we're just checking the location, don't actually transport
	jsr callSpecialCheck ; call special check in map data bank
	ldx saveX
	lda specResult ; later, add support for events other than just map transport
	bne doMove ; transport activated, so go ahead and do move

	; check to see if target tile is clear
	ldy checkOffset,x
	lda levelDataA,y
	and checkMask,x
	bne endJoy ; a tile's in the way, don't allow movement
	
doMove
	; special scroll check -- on page boundaries
	; for left and down, the scroll mode needs
	; to be set to the "special scroll mode"
	; or there will be a gap in tiles.
	; M_SCRL -> M_SCRLS   M_SCRD -> M_SCRDS
	ldy specMoveCheck,x	; figure out which coordinate to check (X or Y)
	lda tempX,y
	and #$0F 				; see if it's on a map page boundary
	bne notSpecialMove
	lda jSpecScroll,x		; use special scroll mode table
	bne special
notSpecialMove
	lda jScroll,x 			; use regular scroll mode table
special
	sta mode

	lda tempX	; save new locX
	sta locX
	lda tempY 	; save new locY
	sta locY
	lda scrL,x 	; set up low address of scroll routine
	sta temp
	lda scrH,x 	; set up high address of scroll routine
	sta temp2
	jmp (temp) 	; call the scrolling function (shifts all the map tiles over)
rtnScroll
	

endJoy ;-----------------------------------------------------
	cld

	lda #C_SCR
	sta mode_cnt

	; De-bounce
	lda SWCHA
	eor #$FF
	beq debounce
	lda flag
	and #%10111111
	sta flag
debounce

	; Joystick button reloads entire screen 
	; (for debugging)
	lda INPT4
	bmi noButton
	lda #M_LOAD
	sta mode
	lda #C_LOAD
	sta mode_cnt
noButton

	; Check for special events if the character moved
;	lda mode
;	and #SCROLL_MASK
;	bne skipSpecialCheck ; if didn't move, no need to check
;	jmp callSpecialCheck ; call special check in map data bank
;rtnCallSpecialCheck
;skipSpecialCheck


skipOS
	lda flag ; check for skip vblank flag
	bmi quitOS

endOSB
	lda INTIM	; We finished, but wait for timer
	bne endOSB	; by looping till zero
	
quitOS
	jmp rtnOverscan
	;--------------------------------------------------------------------


;--------------------------------------------------------------------------
; VBlank
;--------------------------------------------------------------------------
; Game Logic
;--------------------------------------------------------------------------
VBlankB
	; *****************
	; Water Animation
	; *****************
	lda frame
	and #%00001111
	bne noChange

	ldy #50

	ldx tileSet
	lda tileAnimSetup,x
	bmi skipWater
	bne WaterLoop2

WaterLoop
	ldx levelDataA,y
	txa
	and #%11010000
	cmp #$10
	bne noWater1
	txa
	eor #%00100000
	tax
noWater1
	txa
	and #%00001101
	cmp #$01
	bne noWater2
	txa
	eor #%00000010
	tax
noWater2
	txa
	stx levelDataA,y
	dey
	bpl WaterLoop
noChange
	jmp skipWater

	;------------------------------

WaterLoop2
	ldx levelDataA,y
	txa
	and #%11100000
	cmp #%11000000
	bne noWater12
	txa
	eor #%00010000
	tax
noWater12
	txa
	and #%00001110
	cmp #%00001100
	bne noWater22
	txa
	eor #%00000001
	tax
noWater22
	txa
	stx levelDataA,y
	dey
	bpl WaterLoop2






skipWater

;	sta WSYNC
;	sta WSYNC
;	sta WSYNC
;	sta WSYNC
;	sta WSYNC
;	sta WSYNC

	jmp rtnVBlank






;--------------------------------------------------------------------------
; Draw TV Pictures
;--------------------------------------------------------------------------
;
;--------------------------------------------------------------------------
mapKernal

	sta HMCLR

	; Draw your character
	lda levelDataA+MANOFFSET
	sta backChar
	lda #$F0
	ora levelDataA+MANOFFSET
	sta levelDataA+MANOFFSET

pictureLoopB
	lda INTIM	;check timer for end of VBLANK period
	bne pictureLoopB	;loop until it reaches 0

	lda #$20
;	sta COLUBK
	sta COLUPF

	lda #$80
	sta WSYNC
	sta VBLANK  	;end screen blank
	
	ldx #8
topBar
	sta WSYNC
	dex
	bne topBar
	ldx #$02
	stx COLUPF
;	sta COLUBK

;	ldx #5
;topDiv
;	sta WSYNC
;	dex
;	bne topDiv
	
	

	; Wait 18 more lines
;	lda #TOPBLANKTIME
;	sta TIM64T

;topBlankLoop
;	lda INTIM	;check timer for end of VBLANK period
;	bne topBlankLoop	;loop until it reaches 0
;	sta WSYNC

	lda #$08
	sta COLUPF
	lda #255
	sta ENAM0
	sta PF1
	sta PF2
	sta PF0

	; tilePageSetup - sets up the tile page points to point to the right page in memory
	ldx tileSet   ;load up the page value for the font
	lda tileSetHArray,x
	sta grfxBuffer+1
	sta grfxBuffer+3
	sta grfxBuffer+5
	sta grfxBuffer+7
	sta grfxBuffer+9
	sta grfxBuffer+11
	sta grfxBuffer+13
	sta grfxBuffer+15
	sta grfxBuffer+17
	sta grfxBuffer+19

	sta WSYNC
	sta WSYNC
;	ldx tileSet
	lda bkColorArray,x
	sta bkcolor
	sta WSYNC
	sta COLUPF
	sta COLUBK

	lda #0
	sta temp2
	sta PF1
	sta PF0
	sta PF2

	;--------------------------
ScanLoop:
;	ldx #28
;	stx TIM8T

;	ldy linecolor			;3
;	sty COLUPF				;3

	tay

	lax levelDataA+1,y
	and #$0f  
	sta grfxBuffer+10
	txa
	lsr
	lsr
	lsr
	lsr
	sta grfxBuffer+12


	lda pf0shading,x
	and #$F0
	sta temp				; 3 extra

	ldx levelDataA,y
	lda pf0shading,x
;	and #$0F
	lsr
	lsr
	lsr
	lsr
	ora temp
	sta PF2

;	lda bkcolor			;3
;	sta COLUPF				;3

	lax levelDataA,y
	and #$0f  
	sta grfxBuffer+14
	txa
	lsr
	lsr
	lsr
	lsr
	sta grfxBuffer+16



	; Determine color of PF for current line
	; based on tiles present in line
	lda pfcolors,x			; 4     
	ldx levelDataA+1,y	; 4
	ora pfcolors,x			; 4
	ldx levelDataA+3,y	; 4
	ora pfcolors,x			; 4
	ldx levelDataA+4,y	; 4
	ora pfcolors,x			; 4
	ldx levelDataA+2,y	;   needed anyway
	ora pfcolors,x			; 4
	clc						; carry condition is unknown (depends on lsr's above)
	adc tileSet			; Add in offset to current color set (determined by map)
	tay						; move line color number into Y
	lda pfColorArray,y	; get pfcolor for this line
	sta linecolor			; set line color
	ldy temp2				; restore Y
	
	txa
	
	and #$0f  
	sta grfxBuffer+6
	txa
	lsr
	lsr
	lsr
	lsr
	sta grfxBuffer+8

	lda pf0shading,x
	and #$F0				; 2 extra
	sta PF0

	lax levelDataA+3,y
	and #$0f
	sta grfxBuffer+2
	txa
	lsr
	lsr
	lsr
	lsr
	sta grfxBuffer+4

	lda pf0shading,x
	asl
	asl
	asl
	asl
	sta temp

	ldx levelDataA+4,y
	lda pf0shading,x
	and #$0F				; 2 extra
	ora temp				; 3 extra
	sta PF1

	txa
	and #$0f  
	sta grfxBuffer+18
	txa
	lsr
	lsr
	lsr
	lsr
	sta grfxBuffer+0
	
;textTimer
;	ldy INTIM
;	bne textTimer

	jsr println
	lda temp2
	
;	clc ; carry clear is the println loop exit condition

	adc #$05
	cmp #$32
	sta temp2

	beq quitScanLoop
	jmp ScanLoop
quitScanLoop


	sta WSYNC
	sta WSYNC
	lda #$08
	sta COLUPF
	lda #255
	sta PF0
	sta PF1
	sta PF2	
	sta WSYNC
	lda #0
	sta ENAM0
	sta COLUBK

;	ldx #26
;ScanLoop2:
;	sta WSYNC
;	dex
;	bne ScanLoop2

	lda #2 ;40 for 269 lines
	sta TIM64T

	

	lda #255
;	sta COLUPF
	sta WSYNC

	lda #$02
	sta COLUBK
	sta COLUPF
	lda #0
	sta CTRLPF

	sta HMCLR

	ldx #11
extraLines
	sta WSYNC
	dex
	bne extraLines

	ldx #$06
	stx COLUPF

	ldx #8
bottomBar
	sta WSYNC
	dex
	bne bottomBar

	stx COLUPF

	jmp rtnKernal


;-------------------------------------------------------------------------
	align 256
	; Tile data (160 bytes)
charData2
	include tiles2.h
;-------------------------------------------------------------------------

	; Joystick/map movement handling tables
	; Used in overscan.
joyDir ; right/left/down/up
	byte 0,2,3,0, 1,1,1,1, 0,3,3,3, 3,3,3,3
xMov ; X movement
	byte $01,$99,$00,$00
yMov ; Y movement
	byte $00,$00,$99,$01
jScroll ; regular scroll modes
	byte M_SCRL,M_SCRR,M_SCRU,M_SCRD
jSpecScroll ; special scroll modes (only L and D have them)
	byte M_SCRLS,M_SCRR,M_SCRU,M_SCRDS
scrL ; pointers to scroll routines
	byte <scrollRight,<scrollLeft,<scrollDown,<scrollUp
scrH
	byte >scrollRight,>scrollLeft,>scrollDown,>scrollUp
checkOffset ; where in tile data to check for tile obstacle
	byte MANOFFSET,MANOFFSET-1,MANOFFSET-5,MANOFFSET+5
checkMask ; mask to check for an obstacle in the tiles
	byte $0F,$0F,$F0,$F0
specMoveCheck ; offset to check for X or Y for special scroll modes
	byte 0,0,1,1


;-------------------------------------------------------------------------
	align 256
	; Tile data (160 bytes)
charData3
	include tiles3.h
;-------------------------------------------------------------------------

	; Table to determine which cell to load for current fram
	; when a new map strip is being built.  Used in overscan.
	; order L,R,U,D, LS,RSx,US,DSx
scrollScreenA
	byte 1,0,0,2, 0,1,2,0
scrollScreenB
	byte 3,2,1,3, 2,3,3,1

tileAnimSetup ; determines which tiles are animated (0=water,1=door/wall,128=none)
	byte 0,128

	; Sets of playfield shading colors
pfColorArray
	;set   0   1  2    3   4 5 6 7
	byte $80,$F0,$80,$24,$80,0,0,0 ; water
	byte $02,$2F,$02,$02,$02,0,0,0 ; walls/buildings
	byte $f0,$F0,$f0,$f2,$f0,0,0,0 ; rocks

	; Background colors for color sets
bkColorArray
	byte $C0 ; color set 1 (green forest)
	byte $00 ; color set 2 (inside house/castle)
	byte $00 ; color set 3 (black forest)
	byte $F0 ; color set 4 (mountain)
	byte $00 ; color set 5 (dungeon)

	; Array of high byte pointers to tile data sets
tileSetHArray
	byte >charData1, >charData2, >charData1, >charData3, >charData4 ; , >charData5

;-------------------------------------------------------------------------
	align 256
	; Tile data (160 bytes)
charData4
	include tiles4.h
;-------------------------------------------------------------------------

	; Tiles for one byte code
;	%10111011 = random rocks tile code   %10011001 = random trees tile code
oneByteTile
	byte $11,$EE,$99,$99,$BB,$11
	; Sizes for one byte code
oneByteSize
	byte 1,10,3,5,5,10

	; fill block X and Y sizes
blockX
	byte 1,2,1,4, 1,2,5,8, 10, 1,5,1, 4, 10,10,10
blockY
	byte 1,1,2,1, 4,2,3,10, 1,10,1,5, 10,4 , 8,10

	; Some random numbers for generating random trees and rocks
randomArray
	byte 56,72,243,123, 74,198,2,34, 203,172,8,129, 192,37,198,23

XPosition
	byte 4,0,0,1,1, 2,2,3,3,4
YPosition
	byte 0,5,10,15,20, 25,30,35,40,45

tileType
	byte $11,$66,$CC,$DD
	byte $55,$44,$22,$EE
	; special tile setups
	byte %10011001,%10111011,$33,$77 ; rand trees, rand rocks, waterB, rockB

;-------------------------------------------------------------------------
	align 256
	; Tile data (160 bytes)
charData5
	include tiles5.h
;-------------------------------------------------------------------------




;==========================================================================
; Call to inventory display
;==========================================================================
	org $1Fc0
callInvDisp
	ldx BANK2   ; switch to bank 2
	nop         ; 1FE3 jsr Bank2Subroutine
	nop         ; .
	nop         ; .
	nop         ; 1FE6 lda $1FF8  (Switch back to bank 1)        
	nop         ; .
	nop         ; .
;	rts
	jmp rtnKernal

;==========================================================================
; Call to special check
;==========================================================================
	org $1Fd0
callSpecialCheck
	ldx BANK2   ; switch to bank 2
	nop         ; 1FE3 jsr Bank2Subroutine
	nop         ; .
	nop         ; .
	nop         ; 1FE6 lda $1FF8  (Switch back to bank 1)        
	nop         ; .
	nop         ; .
	rts
;	jmp rtnCallSpecialCheck

;==========================================================================
; Call to level get
;==========================================================================
	org $1Fe0
callLevelGet
	ldx BANK2  ; switch to bank 2
	nop         ; 1FE3 jsr Bank2Subroutine
	nop         ; .
	nop         ; .
	nop         ; 1FE6 lda $1FF8  (Switch back to bank 1)        
	nop         ; .
	nop         ; .
	jmp rtnCallLevelGet


;---------------------------------------------------------------------------
; Program Startup
;---------------------------------------------------------------------------
	org $1FF0
	jmp StartB ; if 2600 starts in another bank, it'll drop in here
	org $1FFC
	word StartB
	word StartB
	include bank2.asm